@@ -60,6 +60,12 @@ typedef struct {
   unsigned int n_max;
 } DiffDataField;
 
+typedef enum {
+  NORM1,
+  NORM2,
+  MAX_ERR
+} ErrorMethod;
+
 #define DOUBLEEQUAL_TOTAL 0.0000000001
 #define DOUBLEEQUAL_REL 0.00001
 
@@ -79,11 +85,11 @@ static char ** getVars(void *vars, unsigned int* nvars)
   }
 
   /* Allocate a new string array to contain the variable names. */
-  cmpvars = (char**)GC_malloc(sizeof(char*)*(ncmpvars));
+  cmpvars = (char**)omc_alloc_interface.malloc(sizeof(char*)*(ncmpvars));
 
   /* Copy the variable names from the MetaModelica list to the string array. */
   for(; MMC_NILHDR != MMC_GETHDR(vars); vars = MMC_CDR(vars)) {
-    cmpvars[i++] = GC_strdup(MMC_STRINGDATA(MMC_CAR(vars)));
+    cmpvars[i++] = omc_alloc_interface.malloc_strdup(MMC_STRINGDATA(MMC_CAR(vars)));
   }
 
   *nvars = ncmpvars;
@@ -159,6 +165,55 @@ static char almostEqualWithDefaultTolerance(double a, double b)
   return almostEqualRelativeAndAbs(a,b,DOUBLEEQUAL_REL,DOUBLEEQUAL_TOTAL);
 }
 
+static double deltaData(ErrorMethod errMethod, DataField *time, DataField *reftime, DataField *data, DataField *refdata)
+{
+  unsigned int i, iRef, i2;
+  double res,res0, val, valRef, t;
+  res = 0;
+  res0 = 0;
+  i = 0;
+  for (iRef=0;iRef < reftime->n;iRef++){
+    valRef = refdata->data[iRef];
+    t = reftime->data[iRef];
+    //get left and right reference point to interpolate
+    while((time->data[i] < t))
+    {
+      i++;
+    }
+    i2 = i+1;
+    //there is a result value at time t
+    if (fabs(time->data[i]-t) <= fmax((0.0001*time->data[time->n]),1e-12))
+    {
+      val = data->data[i];
+    }
+    //interpolate result value at time t
+    else
+    {
+      //printf("xl %f   xr %f    tl %f    tr %f  \n", data->data[i], data->data[i2], time->data[i], time->data[i2]);
+      val = (data->data[i2] - data->data[i])/(time->data[i2] - time->data[i])*(t - time->data[i])+data->data[i];
+    }
+    switch(errMethod){
+      case NORM1:
+        res0 += fabs(valRef-val);  break;
+      case NORM2:
+        res0 += pow((valRef-val),2); break;
+      case MAX_ERR:
+        res0 = fmax(fabs(valRef-val),res0); break;
+      default:
+        res0 += fabs(valRef-val); break;
+    }
+    //fprintf(stderr, "at time %f, val: %f and valRef: %f  and res %f\n",t,val,valRef, res0);
+  }
+  switch(errMethod){
+  case NORM2:
+    res = sqrt(res0); break;
+  default:
+    res = res0; break;
+  }
+  return res;
+}
+
+
 static unsigned int cmpData(int isResultCmp, char* varname, DataField *time, DataField *reftime, DataField *data, DataField *refdata, double reltol, double abstol, DiffDataField *ddf, char **cmpdiffvars, unsigned int vardiffindx, int keepEqualResults, void **diffLst, const char *prefix)
 {
   unsigned int i,j,k,j_event;
@@ -173,7 +228,7 @@ static unsigned int cmpData(int isResultCmp, char* varname, DataField *time, Dat
   if (!isResultCmp) {
     fname = (char*) malloc(25 + strlen(prefix) + strlen(varname));
     sprintf(fname, "%s.%s.csv", prefix, varname);
-    fout = fopen(fname,"w");
+    fout = omc_fopen(fname,"w");
     if (fout) {
       fprintf(fout, "time,reference,actual,err,relerr,threshold\n");
     }
@@ -494,7 +549,7 @@ static int writeLogFile(const char *filename,DiffDataField *ddf,const char *f,co
   FILE* fout;
   unsigned int i;
   /* fprintf(stderr, "writeLogFile: %s\n",filename); */
-  fout = fopen(filename, "w");
+  fout = omc_fopen(filename, "w");
   if (!fout)
     return -1;
 
@@ -548,27 +603,26 @@ void* SimulationResultsCmp_compareResults(int isResultCmp, int runningTestsuite,
   ddf.n=0;
   ddf.n_max=0;
   len = 1;
+  int offset, offsetRef;
 
   /* open files */
   /*  fprintf(stderr, "Open File %s\n", filename); */
   if (UNKNOWN_PLOT == SimulationResultsImpl__openFile(filename,&simresglob_c)) {
-    char *str = (char*) GC_malloc(25+strlen(filename));
-    void *res = NULL;
-    *str = 0;
-    strcat(strcat(str,"Error opening file: "), filename);
-    res = mmc_mk_scon(str);
-    GC_free(str);
-    return mmc_mk_cons(res,mmc_mk_nil());
+    c_add_message(NULL,-1,ErrorType_scripting,ErrorLevel_error,gettext("Error opening file: %s"),&filename,1);
+    if (success) {
+      *success = 0;
+      return mmc_mk_nil();
+    }
+    MMC_THROW();
   }
   /* fprintf(stderr, "Open File %s\n", reffilename); */
   if (UNKNOWN_PLOT == SimulationResultsImpl__openFile(reffilename,&simresglob_ref)) {
-    char *str = (char*) GC_malloc(35+strlen(reffilename));
-    void *res = NULL;
-    *str = 0;
-    strcat(strcat(str,"Error opening reference file: "), reffilename);
-    res = mmc_mk_scon(str);
-    GC_free(str);
-    return mmc_mk_cons(res,mmc_mk_nil());
+    c_add_message(NULL,-1,ErrorType_scripting,ErrorLevel_error,gettext("Error opening reference file: %s"),&reffilename,1);
+    if (success) {
+      *success = 0;
+      return mmc_mk_nil();
+    }
+    MMC_THROW();
   }
 
   size = SimulationResultsImpl__readSimulationResultSize(filename,&simresglob_c);
@@ -584,7 +638,14 @@ void* SimulationResultsCmp_compareResults(int isResultCmp, int runningTestsuite,
   if (ncmpvars==0) {
     suggestReadAll = 1;
     cmpvars = getVars(allvarsref,&ncmpvars);
-    if (ncmpvars==0) return mmc_mk_cons(mmc_mk_scon("Error Get Vars!"),mmc_mk_nil());
+    if (ncmpvars==0) {
+      c_add_message(NULL,-1,ErrorType_scripting,ErrorLevel_error,gettext("Error getting variables"),NULL,0);
+      if (success) {
+        *success = 0;
+        return mmc_mk_nil();
+      }
+      MMC_THROW();
+    }
   }
 #ifdef DEBUGOUTPUT
   fprintf(stderr, "Compare Vars:\n");
@@ -597,14 +658,24 @@ void* SimulationResultsCmp_compareResults(int isResultCmp, int runningTestsuite,
   timeVarNameRef = getTimeVarName(allvarsref);
   time = getData(timeVarName,filename,size,suggestReadAll,&simresglob_c,runningTestsuite);
   if (time.n==0) {
-    return mmc_mk_cons(mmc_mk_scon("Error get time!"),mmc_mk_nil());
+    c_add_message(NULL,-1,ErrorType_scripting,ErrorLevel_error,gettext("Error getting time"),NULL,0);
+    if (success) {
+      *success = 0;
+      return mmc_mk_nil();
+    }
+    MMC_THROW();
   }
   /* fprintf(stderr, "get reftime\n"); */
   timeref = getData(timeVarNameRef,reffilename,size_ref,suggestReadAll,&simresglob_ref,runningTestsuite);
   if (timeref.n==0) {
-    return mmc_mk_cons(mmc_mk_scon("Error get ref time!"),mmc_mk_nil());
+    c_add_message(NULL,-1,ErrorType_scripting,ErrorLevel_error,gettext("Error getting time from reference file"),NULL,0);
+    if (success) {
+      *success = 0;
+      return mmc_mk_nil();
+    }
+    MMC_THROW();
   }
-  cmpdiffvars = (char**)GC_malloc(sizeof(char*)*(ncmpvars));
+  cmpdiffvars = (char**)omc_alloc_interface.malloc(sizeof(char*)*(ncmpvars));
   /* check if time is larger or less reftime */
   res = mmc_mk_nil();
   if (fabs(time.data[time.n-1]-timeref.data[timeref.n-1]) > reltol*fabs(timeref.data[timeref.n-1])) {
@@ -617,6 +688,9 @@ void* SimulationResultsCmp_compareResults(int isResultCmp, int runningTestsuite,
     "File[%d]=%f\n",timeref.n,timeref.data[timeref.n-1],time.n,time.data[time.n-1]);
     c_add_message(NULL,-1, ErrorType_scripting, ErrorLevel_warning, buf, NULL, 0);
   }
+  /* calculate offsets */
+  for(offset=0; offset<time.n-1 && time.data[offset] == time.data[offset+1]; ++offset);
+  for(offsetRef=0; offsetRef<timeref.n-1 && timeref.data[offsetRef] == timeref.data[offsetRef+1]; ++offsetRef);
   var1=NULL;
   var2=NULL;
   /* compare vars */
@@ -628,7 +702,7 @@ void* SimulationResultsCmp_compareResults(int isResultCmp, int runningTestsuite,
       free(var1);
       var1 = NULL;
     }
-    var1 = (char*) GC_malloc(len+10);
+    var1 = (char*) omc_alloc_interface.malloc(len+10);
     k = 0;
     for (j=0;j<len;j++) {
       if (var[j] !='\"' ) {
@@ -670,6 +744,11 @@ void* SimulationResultsCmp_compareResults(int isResultCmp, int runningTestsuite,
       ngetfailedvars++;
       continue;
     }
+    /* adjust initial data points */
+    for(j=offset; j>0; j--)
+      data.data[j-1] = data.data[j];
+    for(j=offsetRef; j>0; j--)
+      dataref.data[j-1] = dataref.data[j];
     /* compare */
     if (isHtml) {
       vardiffindx = cmpDataTubes(isResultCmp,var,&time,&timeref,&data,&dataref,reltol,rangeDelta,reltolDiffMaxMin,&ddf,cmpdiffvars,vardiffindx,keepEqualResults,&res,resultfilename,1,htmlOut);
@@ -728,3 +807,183 @@ void* SimulationResultsCmp_compareResults(int isResultCmp, int runningTestsuite,
   return res;
 }
 
+
+/* Common, huge function, for both result comparison and result diff */
+double SimulationResultsCmp_deltaResults(const char *filename, const char *reffilename, const char *methodname, void *vars)
+{
+  double res = 0;
+  unsigned int i,size,size_ref, len, k, j;
+  unsigned int ncmpvars = 0;
+  void *allvars,*allvarsref;
+  char *var,*var1;
+  char **cmpvars=NULL;
+  int suggestReadAll=0;
+  DataField time,timeref,data,dataref;
+  const char *timeVarName, *timeVarNameRef;
+  int offset, offsetRef;
+  const char *msg[2] = {"",""};
+
+  /* choose error method */
+  ErrorMethod errMethod;
+
+  if (0 == strcmp(methodname, "1norm")){
+    errMethod = NORM1;
+  }
+  else if (0 == strcmp(methodname, "2norm")){
+    errMethod = NORM2;
+  }
+  else if (0 == strcmp(methodname, "maxerr")){
+    errMethod = MAX_ERR;
+  }
+  else {
+    msg[0] = methodname;
+    c_add_message(NULL,-1, ErrorType_scripting, ErrorLevel_warning, gettext("Unknown method string: %s. 1-Norm is chosen."), msg, 1);
+    errMethod = NORM1;
+  }
+
+  /* open files */
+  /*  fprintf(stderr, "Open File %s\n", filename); */
+
+  SimulationResultsImpl__close(&simresglob_c);
+  SimulationResultsImpl__close(&simresglob_ref);
+
+  if (UNKNOWN_PLOT == SimulationResultsImpl__openFile(filename,&simresglob_c)) {
+    msg[0] = filename;
+    c_add_message(NULL,-1, ErrorType_scripting, ErrorLevel_error, gettext("Error opening file: %s."), msg, 1);
+    return -1;
+  }
+  /* fprintf(stderr, "Open File %s\n", reffilename); */
+  if (UNKNOWN_PLOT == SimulationResultsImpl__openFile(reffilename,&simresglob_ref)) {
+    msg[0] = filename;
+    c_add_message(NULL,-1, ErrorType_scripting, ErrorLevel_error, gettext("Error opening reference file: %s."), msg, 1);
+    return -1;
+  }
+
+  size = SimulationResultsImpl__readSimulationResultSize(filename,&simresglob_c);
+   /*fprintf(stderr, "Read size of File %s size= %d\n", filename,size);*/
+  size_ref = SimulationResultsImpl__readSimulationResultSize(reffilename,&simresglob_ref);
+   /*fprintf(stderr, "Read size of File %s size= %d\n", reffilename,size_ref);*/
+
+  /* get vars to compare */
+  cmpvars = getVars(vars,&ncmpvars);
+  /* if no var compare all vars */
+  allvars = SimulationResultsImpl__readVarsFilterAliases(filename,&simresglob_c);
+  allvarsref = SimulationResultsImpl__readVarsFilterAliases(reffilename,&simresglob_ref);
+  if (ncmpvars==0) {
+      suggestReadAll = 1;
+      cmpvars = getVars(allvarsref,&ncmpvars);
+      if (ncmpvars==0){
+        c_add_message(NULL,-1, ErrorType_scripting, ErrorLevel_error, gettext("Error Getting Vars."), msg, 1);
+        return -1;
+      }
+    }
+  #ifdef DEBUGOUTPUT
+    fprintf(stderr, "Compare Vars:\n");
+    for(i=0;i<ncmpvars;i++)
+      fprintf(stderr, "Var: %s\n", cmpvars[i]);
+  #endif
+
+  /*  get time */
+ /*fprintf(stderr, "get time\n");*/
+  timeVarName = getTimeVarName(allvars);
+  timeVarNameRef = getTimeVarName(allvarsref);
+  time = getData(timeVarName,filename,size,suggestReadAll,&simresglob_c,0);
+  if (time.n==0) {
+    c_add_message(NULL,-1, ErrorType_scripting, ErrorLevel_error, gettext("Error get time!"), msg, 0);
+    return -1;
+  }
+   /*fprintf(stderr, "get reftime\n");*/
+  timeref = getData(timeVarNameRef,reffilename,size_ref,suggestReadAll,&simresglob_ref,0);
+  if (timeref.n==0) {
+    c_add_message(NULL,-1, ErrorType_scripting, ErrorLevel_error, gettext("Error get reference time!"), msg, 0);
+    return -1;
+  }
+
+  /* check if time is larger or less reftime */
+  if (time.data[0] > timeref.data[0]) {
+    c_add_message(NULL,-1, ErrorType_scripting, ErrorLevel_error, gettext("The result file starts before the reference file."), msg, 0);
+    return -1;
+  }
+  if(time.data[time.n-1] < timeref.data[timeref.n-1]){
+    c_add_message(NULL,-1, ErrorType_scripting, ErrorLevel_error, gettext("The result file ends before the reference file."), msg, 0);
+    return -1;
+  }
+
+  /* calculate offsets */
+  for(offset=0; offset<time.n-1 && time.data[offset] == time.data[offset+1]; ++offset);
+  for(offsetRef=0; offsetRef<timeref.n-1 && timeref.data[offsetRef] == timeref.data[offsetRef+1]; ++offsetRef);
+  var1=NULL;
+  /* compare vars */
+  /* fprintf(stderr, "compare vars\n"); */
+  for (i=0;i<ncmpvars;i++) {
+    var = cmpvars[i];
+    len = strlen(var);
+    if (var1) {
+      free(var1);
+      var1 = NULL;
+    }
+    var1 = (char*) omc_alloc_interface.malloc(len+10);
+    k = 0;
+    for (j=0;j<len;j++) {
+      if (var[j] !='\"' ) {
+        var1[k] = var[j];
+        k +=1;
+      }
+    }
+    var1[k] = 0;
+    /* fprintf(stderr, "compare var: %s\n",var); */
+    /* check if in ref_file */
+    dataref = getData(var1,reffilename,size_ref,suggestReadAll,&simresglob_ref,0);
+    if (dataref.n==0) {
+      if (dataref.data) {
+        free(dataref.data);
+      }
+      if (var1) {
+        GC_free(var1);
+        var1 = NULL;
+      }
+      continue;
+    }
+    /*  check if in file */
+    data = getData(var1,filename,size,suggestReadAll,&simresglob_c,0);
+    if (data.n==0)  {
+      if (data.data) {
+        free(data.data);
+      }
+      if (var1) {
+        GC_free(var1);
+        var1 = NULL;
+      }
+      continue;
+    }
+    /* adjust initial data points */
+    for(j=offset; j>0; j--)
+      data.data[j-1] = data.data[j];
+    for(j=offsetRef; j>0; j--)
+      dataref.data[j-1] = dataref.data[j];
+
+    /* calulate delta */
+    res += deltaData(errMethod,&time,&timeref,&data,&dataref);
+
+    /* free */
+    if (dataref.data) {
+      free(dataref.data);
+    }
+    if (data.data) {
+      free(data.data);
+    }
+    if (var1) {
+      GC_free(var1);
+      var1 = NULL;
+    }
+  }
+  if (cmpvars) GC_free(cmpvars);
+  if (time.data) free(time.data);
+  if (timeref.data) free(timeref.data);
+
+  /* close files */
+  SimulationResultsImpl__close(&simresglob_c);
+  SimulationResultsImpl__close(&simresglob_ref);
+  return res;
+}
+
