@@ -1,7 +1,7 @@
 /*
  * This file is part of OpenModelica.
  *
- * Copyright (c) 1998-2014, Open Source Modelica Consortium (OSMC),
+ * Copyright (c) 1998-CurrentYear, Open Source Modelica Consortium (OSMC),
  * c/o Linköpings universitet, Department of Computer and Information Science,
  * SE-58183 Linköping, Sweden.
  *
@@ -34,6 +34,7 @@
  */
 
 #include "delay.h"
+#include "epsilon.h"
 #include "../../util/omc_error.h"
 #include "../../util/ringbuffer.h"
 #include "../../openmodelica.h"
@@ -46,46 +47,37 @@ void printDelayBuffer(void* data, int stream, void* elemPointer);
 
 
 /**
- * @brief Find row with greatest time that is greater than or equal to 'time'
- *
- * So all buffer elements before returned row index need to be removed from buffer.
+ * @brief Find row with greatest time that is smaller than or equal to 'time'.
  *
  * @param[in] time          Time value to search for.
  * @param[in] delayStruct   Ringbuffer with stored delay values.
  *                          Looks like a matrix with columns of type TIME_AND_VALUE.
- * @param[out] foundEvent   Boolean indicating if an event was found while searching for time.
  * @return int              Row with maximum time value smaller equal to time.
  */
-static int findTime(double time, RINGBUFFER *delayStruct, int* foundEvent)
+static int findTime(double time, RINGBUFFER *delayStruct)
 {
   int end = ringBufferLength(delayStruct);
   int pos = 0;
   double curTime, prevTime;
   TIME_AND_VALUE* bufferElem;
 
-  *foundEvent = 0 /* false */;
-
   /* Check if ring buffer is valid */
   assertStreamPrint(NULL, ringBufferLength(delayStruct) > 0, "delay: In function findTime\nEmpty ring buffer.");
   bufferElem = getRingData(delayStruct, pos);
   curTime = bufferElem->t;
 
   /* If searched time is smaller then first element return first position */
-  if(time < curTime) {
+  if (time < curTime) {
     return pos;
   }
 
   /* Search for time starting at begin of ring buffer */
-  while(pos < end-1) {
+  while (pos < end-1) {
     pos++;
     bufferElem = getRingData(delayStruct, pos);
     prevTime = curTime;
     curTime = bufferElem->t;
-    /* Check for an event */
-    if (fabs(prevTime-curTime)< 1e-12) {
-      *foundEvent = 1 /* true */;
-      plotRingBuffer(delayStruct, LOG_UTIL, printDelayBuffer);
-    }
+
     if (curTime > time) {
       pos--;
       // Found time in previous step
@@ -98,6 +90,55 @@ static int findTime(double time, RINGBUFFER *delayStruct, int* foundEvent)
 }
 
 
+/**
+ * @brief Look for events between `oldTime` and `newTime`
+ *
+ * @param[in] time          Time value to search for.
+ * @param[in] delayStruct   Ringbuffer with stored delay values.
+ *                          Looks like a matrix with columns of type TIME_AND_VALUE.
+ * @return modelica_boolean Boolean indicating if an event was found.
+ */
+static modelica_boolean searchEvent(double time, RINGBUFFER *delayStruct)
+{
+  int end = ringBufferLength(delayStruct);
+  int pos = 0;
+  double curTime, prevTime;
+  TIME_AND_VALUE* bufferElem;
+  modelica_boolean foundEvent = FALSE;
+
+  bufferElem = getRingData(delayStruct, pos);
+  curTime = bufferElem->t;
+
+  /* If searched time is smaller then first element we have no event */
+  if (time < curTime) {
+    return FALSE;
+  }
+
+  /* Search for time starting at begin of ring buffer */
+  while (pos < end-1) {
+    pos++;
+    bufferElem = getRingData(delayStruct, pos);
+    prevTime = curTime;
+    curTime = bufferElem->t;
+
+    /* Check for an event */
+    if (fabs(prevTime-curTime) < 1e-12) {
+      foundEvent = TRUE;
+      break;
+    }
+    if (curTime > time) {
+      break;
+    }
+  }
+
+  if (foundEvent) {
+    printRingBuffer(delayStruct, LOG_DEBUG, printDelayBuffer);
+  }
+
+  return foundEvent;
+}
+
+
 /**
  * @brief Store expression value in delay.
  *
@@ -110,25 +151,25 @@ static int findTime(double time, RINGBUFFER *delayStruct, int* foundEvent)
  */
 void storeDelayedExpression(DATA* data, threadData_t *threadData, int exprNumber, double exprValue, double delayTime, double delayMax)
 {
+  RINGBUFFER* delayStruct = data->simulationInfo->delayStructure[exprNumber];
   int row;
-  int foundEvent;
-  int length = ringBufferLength(data->simulationInfo->delayStructure[exprNumber]);
+  int length = ringBufferLength(delayStruct);
   double time = data->localData[0]->timeValue;
   TIME_AND_VALUE tpl;
   TIME_AND_VALUE* lastElem;
 
   assertStreamPrint(threadData, exprNumber < data->modelData->nDelayExpressions, "storeDelayedExpression: invalid expression number %d", exprNumber);
   assertStreamPrint(threadData, 0 <= exprNumber, "storeDelayedExpression: invalid expression number %d", exprNumber);
-  assertStreamPrint(threadData, data->simulationInfo->startTime <= time, "storeDelayedExpression: time is smaller than starting time.");
 
   /* Check if time is greater equal then last stored time in delay structure */
+  /* ph: Is this needed because of event search? */
   if (length > 0) {
-    lastElem = getRingData(data->simulationInfo->delayStructure[exprNumber], length-1);
+    lastElem = getRingData(delayStruct, length-1);
     while (time < lastElem->t && length > 0) {
-      removeLastRingData(data->simulationInfo->delayStructure[exprNumber],1);
-      length = ringBufferLength(data->simulationInfo->delayStructure[exprNumber]);
+      removeLastRingData(delayStruct,1);
+      length = ringBufferLength(delayStruct);
       if (length > 0) {
-        lastElem = getRingData(data->simulationInfo->delayStructure[exprNumber], length-1);
+        lastElem = getRingData(delayStruct, length-1);
       }
     }
   }
@@ -137,10 +178,10 @@ void storeDelayedExpression(DATA* data, threadData_t *threadData, int exprNumber
    * This should happen after an event was found and the event iteration finished */
   if (length > 0) {
     if (fabs(lastElem->t-time) < 1e-10 && fabs(lastElem->value-exprValue) < 1e-10) {
-      /* Remove stuff that is not needed any more */
-      row = findTime(time-delayTime+1e-10, data->simulationInfo->delayStructure[exprNumber], &foundEvent);
-      if(row > 0){
-        dequeueNFirstRingDatas(data->simulationInfo->delayStructure[exprNumber], row);
+      /* Dequeue no longer needed values from ring buffer */
+      row = findTime(time-delayTime+1e-10, delayStruct);
+      if (row > 0) {
+        dequeueNFirstRingDatas(delayStruct, row);
       }
       return;
     }
@@ -149,17 +190,17 @@ void storeDelayedExpression(DATA* data, threadData_t *threadData, int exprNumber
   /* Append expression value to delay ring buffer */
   tpl.t = time;
   tpl.value = exprValue;
-  appendRingData(data->simulationInfo->delayStructure[exprNumber], &tpl);
+  appendRingData(delayStruct, &tpl);
 
-  /* Dequeue not longer needed values from ring buffer */
-  row = findTime(time-delayTime+DBL_EPSILON, data->simulationInfo->delayStructure[exprNumber], &foundEvent);
-  if(row > 0 && !foundEvent){
-    dequeueNFirstRingDatas(data->simulationInfo->delayStructure[exprNumber], row);
+  /* Dequeue no longer needed values from ring buffer */
+  row = findTime(time-delayTime+DBL_EPSILON, delayStruct);
+  if (row > 0 && !searchEvent(time-delayTime+DBL_EPSILON, delayStruct)) {
+    dequeueNFirstRingDatas(delayStruct, row);
   }
 
   /* Debug print */
-  infoStreamPrint(LOG_DELAY, 0, "storeDelayed[%d] (%g,%g) position=%d", exprNumber, time, exprValue, ringBufferLength(data->simulationInfo->delayStructure[exprNumber]));
-  plotRingBuffer(data->simulationInfo->delayStructure[exprNumber], LOG_DELAY, printDelayBuffer);
+  infoStreamPrint(LOG_DELAY, 0, "storeDelayed[%d] (%g,%g) position=%d", exprNumber, time, exprValue, ringBufferLength(delayStruct));
+  printRingBuffer(delayStruct, LOG_DELAY, printDelayBuffer);
 }
 
 
@@ -170,12 +211,11 @@ void storeDelayedExpression(DATA* data, threadData_t *threadData, int exprNumber
  * @param threadData    Pointer to thread data.
  * @param exprNumber    Index of delay expression.
  * @param exprValue     Value of delay expression.
- * @param time          Current simulation time.
  * @param delayTime     Amount of time exprValue should be delayed.
  * @param delayMax      Maximum time to delay exprValue.
  * @return double       Return delayed value.
  */
-double delayImpl(DATA* data, threadData_t *threadData, int exprNumber, double exprValue, double time, double delayTime, double delayMax)
+double delayImpl(DATA* data, threadData_t *threadData, int exprNumber, double exprValue, double delayTime, double delayMax)
 {
   RINGBUFFER* delayStruct = data->simulationInfo->delayStructure[exprNumber];
   double timeStamp;
@@ -185,76 +225,69 @@ double delayImpl(DATA* data, threadData_t *threadData, int exprNumber, double ex
   double dt1;
   double retVal;
   int i;
-  int foundEvent;
   int length = ringBufferLength(delayStruct);
+  double time = data->localData[0]->timeValue;
 
   infoStreamPrint(LOG_DELAY, 0, "delayImpl: exprNumber = %d, exprValue = %g, time = %g, delayTime = %g", exprNumber, exprValue, time, delayTime);
 
   /* Check for errors */
   assertStreamPrint(threadData, 0 <= exprNumber, "invalid exprNumber = %d", exprNumber);
   assertStreamPrint(threadData, exprNumber < data->modelData->nDelayExpressions, "invalid exprNumber = %d", exprNumber);
-  assertStreamPrint(threadData, delayTime >=  0, "Negative delay requested: delayTime = %g", delayTime);
+  assertStreamPrint(threadData, delayTime >= 0, "Negative delay requested: delayTime = %g", delayTime);
+  assertStreamPrint(threadData, delayTime >= DASSL_STEP_EPS, "delayImpl: delayTime is zero or too small.\n" \
+    "OpenModelica doesn't support delay operator with zero delay time.");
+  assertStreamPrint(threadData, delayTime <= delayMax, "Too large delay requested: delayTime = %g, delayMax = %g", delayTime, delayMax);
 
   /* Return expression value before simulation start */
-  if(time <= data->simulationInfo->startTime)
-  {
-    return (exprValue);
+  if (time <= data->simulationInfo->startTime) {
+    return exprValue;
   }
 
   /*  Empty delay buffer at initialization phase */
-  if(length == 0)
-  {
+  if (length == 0) {
     infoStreamPrint(LOG_EVENTS, 0, "delayImpl: Missing initial value, using argument value %g instead.", exprValue);
-    return (exprValue);
+    return exprValue;
   }
 
   /* Return oldest element in ring buffer */
-  if(time <= data->simulationInfo->startTime + delayTime)
-  {
+  if (time <= data->simulationInfo->startTime + delayTime) {
     return ((TIME_AND_VALUE*)getRingData(delayStruct, 0))->value;
   }
   /* return expr(time-delayTime) */
-  else
-  {
+  else {
     timeStamp = time - delayTime;
 
     /* find the row for the lower limit */
-    if(timeStamp > ((TIME_AND_VALUE*)getRingData(delayStruct, length - 1))->t)
-    {
+    if (timeStamp > ((TIME_AND_VALUE*)getRingData(delayStruct, length - 1))->t) {
       /* delay between the last accepted time step and the current time */
       time0 = ((TIME_AND_VALUE*)getRingData(delayStruct, length - 1))->t;
       value0 = ((TIME_AND_VALUE*)getRingData(delayStruct, length - 1))->value;
       time1 = time;
       value1 = exprValue;
-    }
-    else
-    {
-      i = findTime(timeStamp, delayStruct, &foundEvent);
+    } else {
+      i = findTime(timeStamp, delayStruct);
       assertStreamPrint(threadData, i < length, "%d = i < length = %d", i, length);
       time0 = ((TIME_AND_VALUE*)getRingData(delayStruct, i))->t;
       value0 = ((TIME_AND_VALUE*)getRingData(delayStruct, i))->value;
 
       /* was it the last value? */
-      if(i+1 == length)
-      {
+      if (i+1 == length) {
         return value0;
       }
       time1 = ((TIME_AND_VALUE*)getRingData(delayStruct, i+1))->t;
       value1 = ((TIME_AND_VALUE*)getRingData(delayStruct, i+1))->value;
     }
     /* Return left value */
-    if(time0 == timeStamp)
-    {
+    if (time0 == timeStamp) {
       return value0;
     }
     /* Return right value */
-    else if(time1 == timeStamp)
-    {
+    else if (time1 == timeStamp) {
       return value1;
     }
     /* linear interpolation */
-    else
-    {
+    /* FIXME instead of linear, do the same interpolation order as the integrator */
+    else {
       timedif = time1 - time0;
       dt0 = time1 - timeStamp;
       dt1 = timeStamp - time0;
@@ -272,37 +305,24 @@ double delayImpl(DATA* data, threadData_t *threadData, int exprNumber, double ex
  * @param threadData      Used for error handling.
  * @param exprNumber      Index of delay.
  * @param relationIndex   Index of relation used for zero crossing.
- * @param delayValue      Value to store in delay ringbuffer.
  * @param delayTime       Time to delay expValue.
- * @param delayMax        Maximum allowed delay time, defaults to delayTime.
  * @return double         Value of zeroCrossing at current simulation time.
  */
-double delayZeroCrossing(DATA* data, threadData_t *threadData, unsigned int exprNumber, unsigned int relationIndex, double delayValue, double delayTime, double delayMax)
+double delayZeroCrossing(DATA* data, threadData_t *threadData, unsigned int exprNumber, unsigned int relationIndex, double delayTime)
 {
-  int foundEvent;
-  int eventPos;
-  double zeroCrossingValue;
+  RINGBUFFER* delayStruct = data->simulationInfo->delayStructure[exprNumber];
+  double zeroCrossingValue = data->simulationInfo->zeroCrossingsPre[relationIndex];
   double time = data->localData[0]->timeValue;
 
-  RINGBUFFER* delayStruct = data->simulationInfo->delayStructure[exprNumber];
-  zeroCrossingValue = data->simulationInfo->zeroCrossingsPre[relationIndex];
-
-  if (ringBufferLength(delayStruct) == 0)
-  {
+  if (ringBufferLength(delayStruct) == 0) {
     return zeroCrossingValue;
   }
 
-  /* Find first event on ring buffer */
-  findTime(time - delayTime, delayStruct, &foundEvent);
-
   /* Flip sign of ZC if an event was found */
-  if (!foundEvent)
-  {
-    return zeroCrossingValue;
-  }
-  else
-  {
+  if (searchEvent(time - delayTime, delayStruct)) {
     return -zeroCrossingValue;
+  } else {
+    return zeroCrossingValue;
   }
 }
 
