@@ -31,6 +31,7 @@
 #include "setjmp.h"
 #include <stdio.h>
 #include "omc_error.h"
+#include "simulation_options.h"
 /* For MMC_THROW, so we can end this thing */
 #include "../meta/meta_modelica.h"
 
@@ -46,8 +47,8 @@ const int firstOMCErrorStream = 1;
 
 const char *LOG_STREAM_NAME[SIM_LOG_MAX] = {
   "LOG_UNKNOWN",
-  "stdout",
-  "assert",
+  "LOG_STDOUT",
+  "LOG_ASSERT",
 
   "LOG_DASSL",
   "LOG_DASSL_STATES",
@@ -76,6 +77,7 @@ const char *LOG_STREAM_NAME[SIM_LOG_MAX] = {
   "LOG_JAC",
   "LOG_LS",
   "LOG_LS_V",
+  "LOG_MIXED",
   "LOG_NLS",
   "LOG_NLS_V",
   "LOG_NLS_HOMOTOPY",
@@ -104,8 +106,8 @@ const char *LOG_STREAM_NAME[SIM_LOG_MAX] = {
 
 const char *LOG_STREAM_DESC[SIM_LOG_MAX] = {
   "unknown",
-  "this stream is always active, can be disabled with -lv=-stdout",             /* LOG_STDOUT */
-  "this stream is always active, can be disabled with -lv=-assert",             /* LOG_ASSERT */
+  "this stream is always active, can be disabled with -lv=-LOG_STDOUT",         /* LOG_STDOUT */
+  "this stream is always active, can be disabled with -lv=-LOG_ASSERT",         /* LOG_ASSERT */
 
   "additional information about dassl solver",                                  /* LOG_DASSL */
   "outputs the states at every dassl call",                                     /* LOG_DASSL_STATES */
@@ -134,6 +136,7 @@ const char *LOG_STREAM_DESC[SIM_LOG_MAX] = {
   "outputs the jacobian matrix used by ODE solvers",                            /* LOG_JAC */
   "logging for linear systems",                                                 /* LOG_LS */
   "verbose logging of linear systems",                                          /* LOG_LS_V */
+  "logging for mixed systems",                                                  /* LOG_MIXED */
   "logging for nonlinear systems",                                              /* LOG_NLS */
   "verbose logging of nonlinear systems",                                       /* LOG_NLS_V */
   "logging of homotopy solver for nonlinear systems",                           /* LOG_NLS_HOMOTOPY */
@@ -447,6 +450,40 @@ void warningStreamPrintWithEquationIndexes(int stream, FILE_INFO info, int inden
   }
 }
 
+/**
+ * @brief Print warning to stream until limit is reached.
+ *
+ * If `nDisplayed` is larger than user specified display limit for warnings
+ * a info is displayed and no warning will be printed.
+ *
+ * @param stream          Stream to print to.
+ * @param indentNext      Will increase indentation level by one if true.
+ * @param nDisplayed      Number of times this warning was displayed.
+ * @param maxWarnDisplays Maximum allowed warning displays.
+ * @param format          Format string with message to print.
+ * @param ...             Arguments for format string.
+ */
+void warningStreamPrintWithLimit(int stream, int indentNext, unsigned long nDisplayed, unsigned long maxWarnDisplays, const char *format, ...) {
+
+  if (!ACTIVE_WARNING_STREAM(stream)) {
+    return;
+  }
+
+  va_list args;
+
+  /* Display warning */
+  if (nDisplayed <= maxWarnDisplays) {
+    va_start(args, format);
+    va_warningStreamPrint(stream, indentNext, format, args);
+  }
+  if (nDisplayed == maxWarnDisplays) {
+    infoStreamPrint(stream, indentNext, "Too many warnings, reached display limit of %lu. "
+                                        "Suppressing further warning messages of the same type.", maxWarnDisplays);
+    infoStreamPrint(stream, indentNext, "Change limit with simulation flag -%s=<newLimit>", FLAG_NAME[FLAG_LV_MAX_WARN]);
+    messageClose(stream);
+  }
+}
+
 /**
  * @brief Print warning to stream.
  *
@@ -569,17 +606,35 @@ static inline jmp_buf* getBestJumpBuffer(threadData_t *threadData)
   }
 }
 
+/**
+ * @brief Variadic stream print and throw.
+ *
+ * Print message to LOG_ASSERT.
+ *
+ * @param threadData  Thread data for throwing.
+ * @param format      Format string.
+ * @param args        Variadic argument list for format string
+ */
 void va_throwStreamPrint(threadData_t *threadData, const char *format, va_list args)
 {
 #if !defined(OMC_MINIMAL_LOGGING)
-  char logBuffer[SIZE_LOG_BUFFER];
-  vsnprintf(logBuffer, SIZE_LOG_BUFFER, format, args);
-  messageFunction(LOG_TYPE_DEBUG, LOG_ASSERT, omc_dummyFileInfo, 0, logBuffer, 0, NULL);
+  if (useStream[LOG_ASSERT]) {
+    char logBuffer[SIZE_LOG_BUFFER];
+    vsnprintf(logBuffer, SIZE_LOG_BUFFER, format, args);
+    messageFunction(LOG_TYPE_DEBUG, LOG_ASSERT, omc_dummyFileInfo, 0, logBuffer, 0, NULL);
+  }
 #endif
   threadData = threadData ? threadData : (threadData_t*)pthread_getspecific(mmc_thread_data_key);
   longjmp(*getBestJumpBuffer(threadData), 1);
 }
 
+/**
+ * @brief Print message to LOG_ASSERT and throw.
+ *
+ * @param threadData  Thread data for throwing.
+ * @param format      Format string.
+ * @param ...         Additional arguments for format string.
+ */
 void throwStreamPrint(threadData_t *threadData, const char *format, ...)
 {
 #if !defined(OMC_MINIMAL_LOGGING)
@@ -593,15 +648,26 @@ void throwStreamPrint(threadData_t *threadData, const char *format, ...)
 #endif
 }
 
+/**
+ * @brief Print message with equation indices to LOG_ASSERT stream and throw.
+ *
+ * @param threadData    Thread data for throwing.
+ * @param info          File info, can be omc_dummyFileInfo.
+ * @param indexes       Equation indices.
+ * @param format        Format string.
+ * @param ...           Additional arguments for format string.
+ */
 void throwStreamPrintWithEquationIndexes(threadData_t *threadData, FILE_INFO info, const int *indexes, const char *format, ...)
 {
 #if !defined(OMC_MINIMAL_LOGGING)
-  char logBuffer[SIZE_LOG_BUFFER];
-  va_list args;
-  va_start(args, format);
-  vsnprintf(logBuffer, SIZE_LOG_BUFFER, format, args);
-  va_end(args);
-  messageFunction(LOG_TYPE_DEBUG, LOG_ASSERT, info, 0, logBuffer, 0, indexes);
+  if (useStream[LOG_ASSERT]) {
+    char logBuffer[SIZE_LOG_BUFFER];
+    va_list args;
+    va_start(args, format);
+    vsnprintf(logBuffer, SIZE_LOG_BUFFER, format, args);
+    va_end(args);
+    messageFunction(LOG_TYPE_DEBUG, LOG_ASSERT, info, 0, logBuffer, 0, indexes);
+  }
 #endif
   threadData = threadData ? threadData : (threadData_t*)pthread_getspecific(mmc_thread_data_key);
   longjmp(*getBestJumpBuffer(threadData), 1);
