@@ -95,7 +95,7 @@ ShapePropertiesDialog::ShapePropertiesDialog(ShapeAnnotation *pShapeAnnotation,
   // Extent Group Box
   mpExtentGroupBox = new QGroupBox(Helper::extent);
   // Extent1X
-  QList<QPointF> extents = mpShapeAnnotation->getExtents();
+  QVector<QPointF> extents = mpShapeAnnotation->getExtents();
   mpExtent1XLabel = new Label(Helper::extent1X);
   mpExtent1XSpinBox = new DoubleSpinBox;
   mpExtent1XSpinBox->setRange(-std::numeric_limits<double>::max(), std::numeric_limits<double>::max());
@@ -204,7 +204,7 @@ ShapePropertiesDialog::ShapePropertiesDialog(ShapeAnnotation *pShapeAnnotation,
   mpFontNameLabel = new Label(Helper::name);
   mpFontNameComboBox = new QFontComboBox;
   mpFontNameComboBox->insertItem(0, "Default");
-  currentIndex = mpFontNameComboBox->findText(mpShapeAnnotation->getFontName(), Qt::MatchExactly);
+  currentIndex = mpFontNameComboBox->findText(StringHandler::removeFirstLastQuotes(mpShapeAnnotation->getFontName()), Qt::MatchExactly);
   if (currentIndex > -1) {
     mpFontNameComboBox->setCurrentIndex(currentIndex);
   } else {
@@ -406,31 +406,25 @@ ShapePropertiesDialog::ShapePropertiesDialog(ShapeAnnotation *pShapeAnnotation,
   mpPointsTableWidget->setSelectionBehavior(QAbstractItemView::SelectRows);
   mpPointsTableWidget->setSelectionMode(QAbstractItemView::SingleSelection);
   mpPointsTableWidget->setColumnCount(2);
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
   mpPointsTableWidget->horizontalHeader()->setSectionResizeMode(QHeaderView::Stretch);
-#else /* Qt4 */
-  mpPointsTableWidget->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
-#endif
   mpPointsTableWidget->horizontalHeader()->setDefaultAlignment(Qt::AlignLeft);
   QStringList headerLabels;
   headerLabels << "X" << "Y";
   mpPointsTableWidget->setHorizontalHeaderLabels(headerLabels);
   // add points to points table widget
-  QList<QPointF> points = mpShapeAnnotation->getPoints();
+  QVector<QPointF> points = mpShapeAnnotation->getPoints();
   mpPointsTableWidget->setRowCount(points.size());
   int rowIndex = 0;
-  LineAnnotation::LineType lineType = LineAnnotation::ShapeType;
-  if (mpLineAnnotation) lineType = mpLineAnnotation->getLineType();
   foreach (QPointF point, points) {
     QTableWidgetItem *pTableWidgetItemX = new QTableWidgetItem(QString::number(point.x()));
-    if ((rowIndex == 0 || rowIndex == points.size() - 1) && (lineType == LineAnnotation::ConnectionType)) {
+    if ((rowIndex == 0 || rowIndex == points.size() - 1) && (mpLineAnnotation && mpLineAnnotation->isConnection())) {
       pTableWidgetItemX->setFlags(Qt::NoItemFlags);
     } else {
       pTableWidgetItemX->setFlags(pTableWidgetItemX->flags() | Qt::ItemIsEditable);
     }
     mpPointsTableWidget->setItem(rowIndex, 0, pTableWidgetItemX);
     QTableWidgetItem *pTableWidgetItemY = new QTableWidgetItem(QString::number(point.y()));
-    if ((rowIndex == 0 || rowIndex == points.size() - 1) && (lineType == LineAnnotation::ConnectionType)) {
+    if ((rowIndex == 0 || rowIndex == points.size() - 1) && (mpLineAnnotation && mpLineAnnotation->isConnection())) {
       pTableWidgetItemY->setFlags(Qt::NoItemFlags);
     } else {
       pTableWidgetItemY->setFlags(pTableWidgetItemY->flags() | Qt::ItemIsEditable);
@@ -439,7 +433,7 @@ ShapePropertiesDialog::ShapePropertiesDialog(ShapeAnnotation *pShapeAnnotation,
     rowIndex++;
   }
   if (rowIndex > 0) {
-    if (lineType == LineAnnotation::ConnectionType) {
+    if (mpLineAnnotation && mpLineAnnotation->isConnection()) {
       mpPointsTableWidget->setCurrentCell(1, 1);
     } else {
       mpPointsTableWidget->setCurrentCell(0, 0);
@@ -540,11 +534,11 @@ ShapePropertiesDialog::ShapePropertiesDialog(ShapeAnnotation *pShapeAnnotation,
 QString ShapePropertiesDialog::getTitle()
 {
   if (mpLineAnnotation) {
-    if (mpLineAnnotation->getLineType() == LineAnnotation::ConnectionType) {
+    if (mpLineAnnotation->isConnection()) {
       return "Connection";
-    } else if (mpLineAnnotation->getLineType() == LineAnnotation::TransitionType) {
+    } else if (mpLineAnnotation->isTransition()) {
       return "Transition";
-    } else if (mpLineAnnotation->getLineType() == LineAnnotation::InitialStateType) {
+    } else if (mpLineAnnotation->isInitialState()) {
       return "Initial State";
     } else {
       return "Line";
@@ -640,9 +634,7 @@ void ShapePropertiesDialog::fillPickColor()
 
 void ShapePropertiesDialog::movePointUp()
 {
-  LineAnnotation::LineType lineType = LineAnnotation::ShapeType;
-  if (mpLineAnnotation) lineType = mpLineAnnotation->getLineType();
-  if (lineType == LineAnnotation::InitialStateType) {
+  if (mpLineAnnotation && mpLineAnnotation->isInitialState()) {
     return;
   }
   if (mpPointsTableWidget->selectedItems().size() > 0) {
@@ -650,7 +642,7 @@ void ShapePropertiesDialog::movePointUp()
     if (row == 0) {
       return;
     }
-    if (row == 1 && (lineType == LineAnnotation::ConnectionType || lineType == LineAnnotation::TransitionType)) {
+    if (row == 1 && (mpLineAnnotation && (mpLineAnnotation->isConnection() || mpLineAnnotation->isTransition()))) {
       return;
     }
     QTableWidgetItem *pSourceItemX = mpPointsTableWidget->takeItem(row, 0);
@@ -667,9 +659,7 @@ void ShapePropertiesDialog::movePointUp()
 
 void ShapePropertiesDialog::movePointDown()
 {
-  LineAnnotation::LineType lineType = LineAnnotation::ShapeType;
-  if (mpLineAnnotation) lineType = mpLineAnnotation->getLineType();
-  if (lineType == LineAnnotation::InitialStateType) {
+  if (mpLineAnnotation && mpLineAnnotation->isInitialState()) {
     return;
   }
   if (mpPointsTableWidget->selectedItems().size() > 0) {
@@ -677,7 +667,7 @@ void ShapePropertiesDialog::movePointDown()
     if (row == mpPointsTableWidget->rowCount() - 1) {
       return;
     }
-    if (row == mpPointsTableWidget->rowCount() - 2 && (lineType == LineAnnotation::ConnectionType || lineType == LineAnnotation::TransitionType)) {
+    if (row == mpPointsTableWidget->rowCount() - 2 && (mpLineAnnotation && (mpLineAnnotation->isConnection() || mpLineAnnotation->isTransition()))) {
       return;
     }
     QTableWidgetItem *pSourceItemX = mpPointsTableWidget->takeItem(row, 0);
@@ -695,9 +685,7 @@ void ShapePropertiesDialog::movePointDown()
 void ShapePropertiesDialog::addPoint()
 {
   if (mpPointsTableWidget->selectedItems().size() > 0) {
-    LineAnnotation::LineType lineType = LineAnnotation::ShapeType;
-    if (mpLineAnnotation) lineType = mpLineAnnotation->getLineType();
-    if (lineType == LineAnnotation::InitialStateType) {
+    if (mpLineAnnotation && mpLineAnnotation->isInitialState()) {
       return;
     }
     int row = mpPointsTableWidget->selectedItems().at(0)->row();
@@ -713,8 +701,8 @@ void ShapePropertiesDialog::addPoint()
       mpPointsTableWidget->setCurrentCell(row + 1, 0);
     } else {
       /* get middle of two surronding points */
-      QPointF point1(mpPointsTableWidget->item(row, 0)->text().toFloat(), mpPointsTableWidget->item(row, 1)->text().toFloat());
-      QPointF point2(mpPointsTableWidget->item(row + 1, 0)->text().toFloat(), mpPointsTableWidget->item(row + 1, 1)->text().toFloat());
+      QPointF point1(mpPointsTableWidget->item(row, 0)->text().toDouble(), mpPointsTableWidget->item(row, 1)->text().toDouble());
+      QPointF point2(mpPointsTableWidget->item(row + 1, 0)->text().toDouble(), mpPointsTableWidget->item(row + 1, 1)->text().toDouble());
       QPointF point3 = (point1 + point2) / 2;
       /* insert new row */
       mpPointsTableWidget->insertRow(row + 1);
@@ -726,12 +714,10 @@ void ShapePropertiesDialog::addPoint()
       mpPointsTableWidget->setItem(row + 1, 1, pTableWidgetItemY);
       mpPointsTableWidget->setCurrentCell(row + 1, 0);
     }
-  } else if (mpLineAnnotation && mpPointsTableWidget->rowCount() == 2 &&
-             (mpLineAnnotation->getLineType() == LineAnnotation::ConnectionType ||
-              mpLineAnnotation->getLineType() == LineAnnotation::TransitionType)) {
+  } else if (mpLineAnnotation && mpPointsTableWidget->rowCount() == 2 && (mpLineAnnotation->isConnection() || mpLineAnnotation->isTransition())) {
     /* get middle of two surronding points */
-    QPointF point1(mpPointsTableWidget->item(0, 0)->text().toFloat(), mpPointsTableWidget->item(0, 1)->text().toFloat());
-    QPointF point2(mpPointsTableWidget->item(1, 0)->text().toFloat(), mpPointsTableWidget->item(1, 1)->text().toFloat());
+    QPointF point1(mpPointsTableWidget->item(0, 0)->text().toDouble(), mpPointsTableWidget->item(0, 1)->text().toDouble());
+    QPointF point2(mpPointsTableWidget->item(1, 0)->text().toDouble(), mpPointsTableWidget->item(1, 1)->text().toDouble());
     QPointF point3 = (point1 + point2) / 2;
     /* insert new row */
     mpPointsTableWidget->insertRow(1);
@@ -749,10 +735,8 @@ void ShapePropertiesDialog::removePoint()
 {
   if (mpPointsTableWidget->selectedItems().size() > 0) {
     if ((mpLineAnnotation && mpPointsTableWidget->rowCount() > 2) || (mpPolygonAnnotation && mpPointsTableWidget->rowCount() > 4)) {
-      LineAnnotation::LineType lineType = LineAnnotation::ShapeType;
-      if (mpLineAnnotation) lineType = mpLineAnnotation->getLineType();
       int row = mpPointsTableWidget->selectedItems().at(0)->row();
-      if (lineType == LineAnnotation::InitialStateType && row == 0) {
+      if (mpLineAnnotation && mpLineAnnotation->isInitialState() && row == 0) {
         return;
       }
       mpPointsTableWidget->removeRow(row);
@@ -778,7 +762,7 @@ bool ShapePropertiesDialog::applyShapeProperties()
   for (int i = 0 ; i < mpPointsTableWidget->rowCount() ; i++) {
     QTableWidgetItem *pTableWidgetItem = mpPointsTableWidget->item(i, 0); /* point X value */
     bool Ok;
-    pTableWidgetItem->text().toFloat(&Ok);
+    pTableWidgetItem->text().toDouble(&Ok);
     if (!Ok || pTableWidgetItem->text().isEmpty()) {
       QMessageBox::critical(MainWindow::instance(), QString("%1 - %2").arg(Helper::applicationName, Helper::error),
                             GUIMessages::getMessage(GUIMessages::ENTER_VALID_NUMBER).arg("points item ("+  QString::number(i+1) +",0)"), Helper::ok);
@@ -786,7 +770,7 @@ bool ShapePropertiesDialog::applyShapeProperties()
       return false;
     }
     pTableWidgetItem = mpPointsTableWidget->item(i, 1); /* point Y value */
-    pTableWidgetItem->text().toFloat(&Ok);
+    pTableWidgetItem->text().toDouble(&Ok);
     if (!Ok || pTableWidgetItem->text().isEmpty()) {
       QMessageBox::critical(MainWindow::instance(), QString("%1 - %2").arg(Helper::applicationName, Helper::error),
                             GUIMessages::getMessage(GUIMessages::ENTER_VALID_NUMBER).arg("points table ["+  QString::number(i+1) +",1]"), Helper::ok);
@@ -816,7 +800,7 @@ bool ShapePropertiesDialog::applyShapeProperties()
   mpShapeAnnotation->setOrigin(QPointF(mpOriginXSpinBox->value(), mpOriginYSpinBox->value()));
   mpShapeAnnotation->setRotationAngle(mpRotationSpinBox->value());
   if (!mpLineAnnotation && !mpPolygonAnnotation) {
-    QList<QPointF> extents;
+    QVector<QPointF> extents;
     QPointF p1(mpExtent1XSpinBox->value(), mpExtent1YSpinBox->value());
     QPointF p2(mpExtent2XSpinBox->value(), mpExtent2YSpinBox->value());
     extents << p1 << p2;
@@ -839,7 +823,7 @@ bool ShapePropertiesDialog::applyShapeProperties()
     qreal fontSize = 0;
     fontSize = mpFontSizeComboBox->lineEdit()->text().toDouble();
     mpShapeAnnotation->setFontSize(fontSize);
-    QList<StringHandler::TextStyle> textStyles;
+    QVector<StringHandler::TextStyle> textStyles;
     if (mpTextBoldCheckBox->isChecked()) textStyles.append(StringHandler::TextStyleBold);
     if (mpTextItalicCheckBox->isChecked()) textStyles.append(StringHandler::TextStyleItalic);
     if (mpTextUnderlineCheckBox->isChecked()) textStyles.append(StringHandler::TextStyleUnderLine);
@@ -860,9 +844,9 @@ bool ShapePropertiesDialog::applyShapeProperties()
   }
   /* save points */
   mpShapeAnnotation->clearPoints();
-  QList<QPointF> points;
+  QVector<QPointF> points;
   for (int i = 0 ; i < mpPointsTableWidget->rowCount() ; i++) {
-    points.append(QPointF(mpPointsTableWidget->item(i, 0)->text().toFloat(), mpPointsTableWidget->item(i, 1)->text().toFloat()));
+    points.append(QPointF(mpPointsTableWidget->item(i, 0)->text().toDouble(), mpPointsTableWidget->item(i, 1)->text().toDouble()));
   }
   mpShapeAnnotation->setPoints(points);
   /* save bitmap file name and image source */
@@ -914,23 +898,20 @@ bool ShapePropertiesDialog::applyShapeProperties()
 #endif // QT_VERSION_CHECK
     }
   }
-  LineAnnotation::LineType lineType = LineAnnotation::ShapeType;
-  if (mpLineAnnotation) {
-    lineType = mpLineAnnotation->getLineType();
-    if (lineType == LineAnnotation::ConnectionType || lineType == LineAnnotation::TransitionType) {
-      mpLineAnnotation->adjustGeometries();
-    }
+
+  if (mpLineAnnotation && (mpLineAnnotation->isConnection() || mpLineAnnotation->isTransition())) {
+    mpLineAnnotation->adjustGeometries();
   }
   // if nothing has changed then just simply return true.
   if (mOldAnnotation.compare(mpShapeAnnotation->getOMCShapeAnnotation()) == 0) {
     return true;
-  } else if (mpLineAnnotation && lineType == LineAnnotation::ConnectionType) {
+  } else if (mpLineAnnotation && mpLineAnnotation->isConnection()) {
     // create a UpdateConnectionCommand object and push it to the undo stack.
     UpdateConnectionCommand *pUpdateConnectionCommand;
     pUpdateConnectionCommand = new UpdateConnectionCommand(mpLineAnnotation, mOldAnnotation, mpShapeAnnotation->getOMCShapeAnnotation());
     mpShapeAnnotation->getGraphicsView()->getModelWidget()->getUndoStack()->push(pUpdateConnectionCommand);
     mpShapeAnnotation->getGraphicsView()->getModelWidget()->updateModelText();
-  } else if (mpLineAnnotation && lineType == LineAnnotation::TransitionType) {
+  } else if (mpLineAnnotation && mpLineAnnotation->isTransition()) {
     // create a UpdateTransitionCommand object and push it to the undo stack.
     UpdateTransitionCommand *pUpdateTransitionCommand;
     pUpdateTransitionCommand = new UpdateTransitionCommand(mpLineAnnotation, mpLineAnnotation->getCondition(), mpLineAnnotation->getImmediate(), mpLineAnnotation->getReset(),
@@ -939,7 +920,7 @@ bool ShapePropertiesDialog::applyShapeProperties()
                                                            mpLineAnnotation->getPriority(), mpShapeAnnotation->getOMCShapeAnnotation());
     mpShapeAnnotation->getGraphicsView()->getModelWidget()->getUndoStack()->push(pUpdateTransitionCommand);
     mpShapeAnnotation->getGraphicsView()->getModelWidget()->updateModelText();
-  } else if (mpLineAnnotation && lineType == LineAnnotation::InitialStateType) {
+  } else if (mpLineAnnotation && mpLineAnnotation->isInitialState()) {
     // create a UpdateInitialStateCommand object and push it to the undo stack.
     UpdateInitialStateCommand *pUpdateInitialStateCommand;
     pUpdateInitialStateCommand = new UpdateInitialStateCommand(mpLineAnnotation, mOldAnnotation, mpShapeAnnotation->getOMCShapeAnnotation());
@@ -947,8 +928,7 @@ bool ShapePropertiesDialog::applyShapeProperties()
     mpShapeAnnotation->getGraphicsView()->getModelWidget()->updateModelText();
   } else {
     // create a UpdateShapeCommand object and push it to the undo stack.
-    UpdateShapeCommand *pUpdateShapeCommand;
-    pUpdateShapeCommand = new UpdateShapeCommand(mpShapeAnnotation, mOldAnnotation, mpShapeAnnotation->getOMCShapeAnnotation());
+    UpdateShapeCommand *pUpdateShapeCommand = new UpdateShapeCommand(mpShapeAnnotation, mOldAnnotation, mpShapeAnnotation->getOMCShapeAnnotation());
     mpShapeAnnotation->getGraphicsView()->getModelWidget()->getUndoStack()->push(pUpdateShapeCommand);
     mpShapeAnnotation->getGraphicsView()->getModelWidget()->updateClassAnnotationIfNeeded();
     mpShapeAnnotation->getGraphicsView()->getModelWidget()->updateModelText();
