@@ -75,9 +75,8 @@ public:
     SaveInOneFile,
     SaveFolderStructure
   };
-  LibraryTreeItem();
-  LibraryTreeItem(LibraryType type, QString text, QString nameStructure, OMCInterface::getClassInformation_res classInformation,
-                  QString fileName, bool isSaved, LibraryTreeItem *pParent = 0);
+  LibraryTreeItem(QAbstractItemModel *pParent);
+  LibraryTreeItem(LibraryType type, QString text, QString nameStructure, QString fileName, bool isSaved, LibraryTreeItem *pParent = 0);
   ~LibraryTreeItem();
   bool isRootItem() const {return mIsRootItem;}
   int childrenSize() const {return mChildren.size();}
@@ -92,11 +91,16 @@ public:
   void setName(QString name) {mName = name;}
   const QString& getName() const {return mName;}
   void setNameStructure(QString nameStructure) {mNameStructure = nameStructure;}
-  const QString& getNameStructure() {return mNameStructure;}
+  const QString& getNameStructure() const {return mNameStructure;}
   QString getWhereToMoveFMU();
-  void setClassInformation(OMCInterface::getClassInformation_res classInformation);
+  void updateClassInformation();
   void setFileName(QString fileName) {mFileName = fileName;}
   const QString& getFileName() const {return mFileName;}
+  const QString& getVersion() const;
+  const QString& getVersionDate() const;
+  const QString& getVersionBuild() const;
+  const QString& getDateModified() const;
+  const QString& getRevisionId() const;
   bool isFilePathValid();
   void setReadOnly(bool readOnly) {mReadOnly = readOnly;}
   bool isReadOnly() {return mReadOnly;}
@@ -125,6 +129,7 @@ public:
   bool isExpanded() const {return mExpanded;}
   void setNonExisting(bool nonExisting) {mNonExisting = nonExisting;}
   bool isNonExisting() const {return mNonExisting;}
+  bool isEncryptedClass() const {return mFileName.endsWith(".moc");}
   bool isAccessAnnotationsEnabled() const {return mAccessAnnotations;}
   void setAccessAnnotations(bool accessAnnotations) {mAccessAnnotations = accessAnnotations;}
   void setOMSElement(oms_element_t *pOMSComponent) {mpOMSElement = pOMSComponent;}
@@ -164,7 +169,7 @@ public:
   void moveChild(int from, int to);
   void addInheritedClass(LibraryTreeItem *pLibraryTreeItem);
   void removeInheritedClasses();
-  QList<LibraryTreeItem*> getInheritedClasses() const {return mInheritedClasses;}
+  const QList<LibraryTreeItem*> &getInheritedClasses();
   QList<LibraryTreeItem*> getInheritedClassesDeepList();
   LibraryTreeItem *getDirectComponentsClass(const QString &name);
   LibraryTreeItem *getComponentsClass(const QString &name);
@@ -189,40 +194,45 @@ public:
 
   OMCInterface::getClassInformation_res mClassInformation;
   SimulationOptions mSimulationOptions;
-  const QList<ElementInfo *> &getComponentsList();
+  const QList<ElementInfo*> &getComponentsList();
 private:
   bool mIsRootItem;
-  LibraryTreeItem *mpParentLibraryTreeItem;
+  LibraryTreeItem *mpParentLibraryTreeItem = 0;
   QList<LibraryTreeItem*> mChildren;
+  bool mInheritedClassesLoaded = false;
   QList<LibraryTreeItem*> mInheritedClasses;
   QList<ElementInfo*> mComponents;
-  bool mComponentsLoaded;
-  LibraryType mLibraryType;
-  bool mSystemLibrary;
-  ModelWidget *mpModelWidget;
+  bool mComponentsLoaded = false;
+  LibraryType mLibraryType = LibraryTreeItem::Modelica;
+  bool mSystemLibrary = false;
+  ModelWidget *mpModelWidget = 0;
   QString mName;
   QString mParentName;
   QString mNameStructure;
   QString mFileName;
-  bool mReadOnly;
-  bool mIsSaved;
-  SaveContentsType mSaveContentsType;
+  QString mVersionDate;
+  QString mVersionBuild;
+  QString mDateModified;
+  QString mRevisionId;
+  bool mReadOnly = false;
+  bool mIsSaved = false;
+  SaveContentsType mSaveContentsType = LibraryTreeItem::SaveInOneFile;
   QPixmap mPixmap;
   QPixmap mDragPixmap;
   QString mClassTextBefore;
   QString mClassText;
   QString mClassTextAfter;
-  bool mExpanded;
-  bool mNonExisting;
-  bool mAccessAnnotations;
-  oms_element_t *mpOMSElement;
-  oms_system_enu_t mSystemType;
-  oms_component_enu_t mComponentType;
-  oms_connector_t *mpOMSConnector;
-  oms_busconnector_t *mpOMSBusConnector;
-  oms_tlmbusconnector_t *mpOMSTLMBusConnector;
-  const oms_fmu_info_t *mpFMUInfo;
-  const oms_external_tlm_model_info_t *mpExternalTLMModelInfo;
+  bool mExpanded = false;
+  bool mNonExisting = false;
+  bool mAccessAnnotations = false;
+  oms_element_t *mpOMSElement = 0;
+  oms_system_enu_t mSystemType = oms_system_none;
+  oms_component_enu_t mComponentType = oms_component_none;
+  oms_connector_t *mpOMSConnector = 0;
+  oms_busconnector_t *mpOMSBusConnector = 0;
+  oms_tlmbusconnector_t *mpOMSTLMBusConnector = 0;
+  const oms_fmu_info_t *mpFMUInfo = 0;
+  const oms_external_tlm_model_info_t *mpExternalTLMModelInfo = 0;
   QString mSubModelPath;
 signals:
   void loaded(LibraryTreeItem *pLibraryTreeItem);
@@ -281,9 +291,9 @@ public:
                                                Qt::CaseSensitivity caseSensitivity = Qt::CaseSensitive) const;
   LibraryTreeItem* findNonExistingLibraryTreeItem(const QString &name, Qt::CaseSensitivity caseSensitivity = Qt::CaseSensitive) const;
   QModelIndex libraryTreeItemIndex(const LibraryTreeItem *pLibraryTreeItem) const;
-  void addModelicaLibraries();
+  void addModelicaLibraries(const QVector<QPair<QString, QString> > libraries = QVector<QPair<QString, QString> >());
   LibraryTreeItem* createLibraryTreeItem(QString name, LibraryTreeItem *pParentLibraryTreeItem, bool isSaved = true,
-                                         bool isSystemLibrary = false, bool load = false, int row = -1, bool activateAccessAnnotations = false);
+                                         bool isSystemLibrary = false, bool load = false, int row = -1, bool loadingMOL = false);
   LibraryTreeItem* createNonExistingLibraryTreeItem(QString nameStructure);
   void createLibraryTreeItems(QFileInfo fileInfo, LibraryTreeItem *pParentLibraryTreeItem);
   LibraryTreeItem* createLibraryTreeItem(LibraryTreeItem::LibraryType type, QString name, QString nameStructure, QString path, bool isSaved,
@@ -297,7 +307,6 @@ public:
   void removeNonExistingLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem) {mNonExistingLibraryTreeItemsList.removeOne(pLibraryTreeItem);}
   void updateLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
   void updateLibraryTreeItemClassText(LibraryTreeItem *pLibraryTreeItem);
-  void updateLibraryTreeItemClassTextManually(LibraryTreeItem *pLibraryTreeItem, QString contents);
   void updateChildLibraryTreeItemClassText(LibraryTreeItem *pLibraryTreeItem, QString contents, QString fileName);
   void readLibraryTreeItemClassText(LibraryTreeItem *pLibraryTreeItem);
   LibraryTreeItem* getContainingFileParentLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
@@ -307,12 +316,12 @@ public:
   LibraryTreeItem* getLibraryTreeItemFromFile(QString fileName, int lineNumber);
   void showModelWidget(LibraryTreeItem *pLibraryTreeItem, bool show = true);
   void showHideProtectedClasses();
-  bool unloadClass(LibraryTreeItem *pLibraryTreeItem, bool askQuestion = true);
+  bool unloadClass(LibraryTreeItem *pLibraryTreeItem, bool askQuestion = true, bool doDeleteClass = true);
   bool unloadCompositeModelOrTextFile(LibraryTreeItem *pLibraryTreeItem, bool askQuestion = true);
   bool unloadOMSModel(LibraryTreeItem *pLibraryTreeItem, bool doDelete = true, bool askQuestion = true);
   void getExpandedLibraryTreeItemsList(LibraryTreeItem *pLibraryTreeItem, QStringList *pExpandedLibraryTreeItemsList);
   void expandLibraryTreeItems(LibraryTreeItem *pLibraryTreeItem, QStringList expandedLibraryTreeItemsList);
-  void reLoadOMSimulatorModel(const QString &modelName, const QString &editedCref, const QString &snapShot);
+  void reLoadOMSimulatorModel(const QString &modelName, const QString &editedCref, const QString &snapShot, const QString &oldEditedCref, const QString &newEditedCref);
   bool unloadLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem, bool doDeleteClass);
   bool removeLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
   bool deleteTextFile(LibraryTreeItem *pLibraryTreeItem, bool askQuestion = true);
@@ -322,22 +331,24 @@ public:
   void generateVerificationScenarios(LibraryTreeItem *pLibraryTreeItem);
   QString getUniqueTopLevelItemName(QString name, int number = 1);
   void emitDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight) {emit dataChanged(topLeft, bottomRight);}
+  void createLibraryTreeItems(LibraryTreeItem *pLibraryTreeItem);
+  void unloadFileChildren(LibraryTreeItem *pLibraryTreeItem);
+  void emitModelStateChanged(const QString &name) {emit modelStateChanged(name);}
+  bool isCreatingAutoLoadedLibrary() const {return mCreatingAutoLoadedLibrary;}
+  void setCreatingAutoLoadedLibrary(bool creatingAutoLoadedLibrary) {mCreatingAutoLoadedLibrary = creatingAutoLoadedLibrary;}
 private:
   LibraryWidget *mpLibraryWidget;
   LibraryTreeItem *mpRootLibraryTreeItem;
   QList<LibraryTreeItem*> mNonExistingLibraryTreeItemsList;
-  QModelIndex libraryTreeItemIndexHelper(const LibraryTreeItem *pLibraryTreeItem, const LibraryTreeItem *pParentLibraryTreeItem,
-                                         const QModelIndex &parentIndex) const;
+  bool mCreatingAutoLoadedLibrary = false;
+
+  QModelIndex libraryTreeItemIndexHelper(const LibraryTreeItem *pLibraryTreeItem, const LibraryTreeItem *pParentLibraryTreeItem, const QModelIndex &parentIndex) const;
   LibraryTreeItem* getLibraryTreeItemFromFileHelper(LibraryTreeItem *pLibraryTreeItem, QString fileName, int lineNumber);
   void readLibraryTreeItemClassTextFromText(LibraryTreeItem *pLibraryTreeItem, QString contents);
   QString readLibraryTreeItemClassTextFromFile(LibraryTreeItem *pLibraryTreeItem);
-public:
-  void createLibraryTreeItems(LibraryTreeItem *pLibraryTreeItem);
-private:
   LibraryTreeItem* createLibraryTreeItemImpl(QString name, LibraryTreeItem *pParentLibraryTreeItem, bool isSaved = true,
                                              bool isSystemLibrary = false, bool load = false, int row = -1, bool activateAccessAnnotations = false);
-  void createNonExistingLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem, LibraryTreeItem *pParentLibraryTreeItem, bool isSaved = true,
-                                        int row = -1);
+  void createNonExistingLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem, LibraryTreeItem *pParentLibraryTreeItem, bool isSaved = true, int row = -1);
   void createLibraryTreeItemsImpl(QFileInfo fileInfo, LibraryTreeItem *pParentLibraryTreeItem);
   LibraryTreeItem* createLibraryTreeItemImpl(LibraryTreeItem::LibraryType type, QString name, QString nameStructure, QString path, bool isSaved,
                                              LibraryTreeItem *pParentLibraryTreeItem, int row = -1);
@@ -351,13 +362,12 @@ private:
   void unloadClassHelper(LibraryTreeItem *pLibraryTreeItem, LibraryTreeItem *pParentLibraryTreeItem);
   void unloadClassChildren(LibraryTreeItem *pLibraryTreeItem);
   void unloadFileHelper(LibraryTreeItem *pLibraryTreeItem, LibraryTreeItem *pParentLibraryTreeItem);
-public:
-  void unloadFileChildren(LibraryTreeItem *pLibraryTreeItem);
-private:
   void deleteFileHelper(LibraryTreeItem *pLibraryTreeItem, LibraryTreeItem *pParentLibraryTreeItem);
   void deleteFileChildren(LibraryTreeItem *pLibraryTreeItem);
 protected:
   Qt::DropActions supportedDropActions() const override;
+signals:
+  void modelStateChanged(const QString &name);
 };
 
 class LibraryTreeView : public QTreeView
@@ -371,10 +381,10 @@ private:
   QAction *mpOpenClassAction;
   QAction *mpInformationAction;
   QAction *mpNewModelicaClassAction;
-  QAction *mpNewModelicaClassEmptyAction;
   QAction *mpSaveAction;
   QAction *mpSaveAsAction;
   QAction *mpSaveTotalAction;
+  QAction *mpCopyPathAction;
   QAction *mpMoveUpAction;
   QAction *mpMoveDownAction;
   QAction *mpMoveTopAction;
@@ -400,6 +410,7 @@ private:
   QAction *mpNewFolderEmptyAction;
   QAction *mpRenameAction;
   QAction *mpDeleteAction;
+  QAction *mpConvertClassUsesLibrariesAction;
   QAction *mpExportFMUAction;
   QAction *mpExportReadonlyPackageAction;
   QAction *mpExportEncryptedPackageAction;
@@ -409,12 +420,12 @@ private:
   QAction *mpGenerateVerificationScenariosAction;
   QAction *mpFetchInterfaceDataAction;
   QAction *mpTLMCoSimulationAction;
-  QAction *mpNewOMSimulatorModelEmptyAction;
   QAction *mpOMSRenameAction;
   QAction *mpUnloadOMSModelAction;
   void createActions();
   LibraryTreeItem* getSelectedLibraryTreeItem();
-  void libraryTreeItemExpanded(LibraryTreeItem* pLibraryTreeItem);
+  void libraryTreeItemExpanded(LibraryTreeItem *pLibraryTreeItem);
+  void copyClassPathHelper(const QString &classPath);
 public slots:
   void libraryTreeItemExpanded(const QModelIndex &index);
   void libraryTreeItemDoubleClicked(const QModelIndex &index);
@@ -422,10 +433,10 @@ public slots:
   void openClass();
   void openInformationDialog();
   void createNewModelicaClass();
-  void createNewModelicaClassEmpty();
   void saveClass();
   void saveAsClass();
   void saveTotalClass();
+  void copyClassPath();
   void moveClassUp();
   void moveClassDown();
   void moveClassTop();
@@ -448,6 +459,7 @@ public slots:
   void createNewFolderEmpty();
   void renameLibraryTreeItem();
   void deleteTextFile();
+  void convertClassUsesLibraries();
   void exportModelFMU();
   void exportEncryptedPackage();
   void exportReadonlyPackage();
@@ -457,7 +469,6 @@ public slots:
   void generateVerificationScenarios();
   void fetchInterfaceData();
   void TLMSimulate();
-  void createNewOMSModelEmpty();
   void OMSRename();
   void unloadOMSModel();
 protected:
@@ -476,7 +487,7 @@ public:
   LibraryTreeView* getLibraryTreeView() {return mpLibraryTreeView;}
   void openFile(QString fileName, QString encoding = Helper::utf8, bool showProgress = true, bool checkFileExists = false,
                 bool loadExternalModel = false);
-  void openModelicaFile(QString fileName, QString encoding = Helper::utf8, bool showProgress = true);
+  void openModelicaFile(QString fileName, QString encoding = Helper::utf8, bool showProgress = true, bool secondAttempt = false);
   void openEncrytpedModelicaLibrary(QString fileName, QString encoding = Helper::utf8, bool showProgress = true);
   void openCompositeModelOrTextFile(QFileInfo fileInfo, bool showProgress = true);
   void openDirectory(QFileInfo fileInfo, bool showProgress = true);
@@ -486,29 +497,42 @@ public:
   bool saveFile(QString fileName, QString contents);
   bool saveLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
   void saveAsLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
-  bool saveTotalLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
+  void saveTotalLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
   void openLibraryTreeItem(QString nameStructure);
+  void loadAutoLoadedLibrary(const QString &modelName);
+  bool isLoadingLibraries() const {return mLoadingLibraries;}
+  void setLoadingLibraries(bool loadingLibraries) {mLoadingLibraries = loadingLibraries;}
 private:
+  bool mLoadingLibraries;
+  QTimer mAutoLoadedLibrariesTimer;
+  QStringList mAutoLoadedLibrariesList;
   TreeSearchFilters *mpTreeSearchFilters;
   LibraryTreeModel *mpLibraryTreeModel;
   LibraryTreeProxyModel *mpLibraryTreeProxyModel;
   LibraryTreeView *mpLibraryTreeView;
   bool multipleTopLevelClasses(const QStringList &classesList, const QString &fileName);
-  bool saveModelicaLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
-  bool saveModelicaLibraryTreeItemHelper(LibraryTreeItem *pLibraryTreeItem);
-  bool saveModelicaLibraryTreeItemOneFile(LibraryTreeItem *pLibraryTreeItem);
+  bool saveModelicaLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem, bool saveAs);
+  bool saveModelicaLibraryTreeItemHelper(LibraryTreeItem *pLibraryTreeItem, bool saveAs);
+  bool saveModelicaLibraryTreeItemOneFile(LibraryTreeItem *pLibraryTreeItem, bool saveAs);
   void saveChildLibraryTreeItemsOneFile(LibraryTreeItem *pLibraryTreeItem);
   void saveChildLibraryTreeItemsOneFileHelper(LibraryTreeItem *pLibraryTreeItem);
   bool saveModelicaLibraryTreeItemFolder(LibraryTreeItem *pLibraryTreeItem);
-  bool saveTextLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
+  bool saveTextLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem, bool saveAs);
   bool saveOMSLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
   void saveOMSLibraryTreeItemHelper(LibraryTreeItem *pLibraryTreeItem, QString fileName);
   bool saveCompositeModelLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
   bool saveAsCompositeModelLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
   bool saveAsOMSLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem);
   bool saveCompositeModelLibraryTreeItem(LibraryTreeItem *pLibraryTreeItem, QString fileName);
-  bool saveTotalLibraryTreeItemHelper(LibraryTreeItem *pLibraryTreeItem);
+  void saveTotalLibraryTreeItemHelper(LibraryTreeItem *pLibraryTreeItem);
+  bool resolveConflictWithLoadedLibraries(const QString &library, const QStringList classes);
+  static void cancelLoadingLibraries(const QStringList classes);
+private slots:
+  void handleAutoLoadedLibrary();
 public slots:
+  void loadSystemLibrary();
+  void loadSystemLibrary(const QString &library, QString version = QString("default"), bool secondAttempt = false);
+  void scrollToActiveLibraryTreeItem();
   void searchClasses();
 };
 
