@@ -59,7 +59,6 @@
 #ifndef OM_OMEDIT_ENABLE_QTWEBENGINE
 #include <QtWebKit>
 #endif
-#include <QtXmlPatterns>
 #include <QSplitter>
 #include <QUndoStack>
 #include <QUndoView>
@@ -129,7 +128,6 @@ private:
   Element *mpClickedState;
   bool mIsMovingComponentsAndShapes;
   bool mRenderingLibraryPixmap;
-  bool mSharpLibraryPixmap;
   QList<Element*> mElementsList;
   // A list of components that are not deleted but are removed from scene.
   QList<Element*> mOutOfSceneElementsList;
@@ -153,7 +151,9 @@ private:
   RectangleAnnotation *mpRectangleShapeAnnotation;
   EllipseAnnotation *mpEllipseShapeAnnotation;
   TextAnnotation *mpTextShapeAnnotation;
+  TextAnnotation *mpErrorTextShapeAnnotation;
   BitmapAnnotation *mpBitmapShapeAnnotation;
+  QAction *mpParametersAction;
   QAction *mpPropertiesAction;
   QAction *mpRenameAction;
   QAction *mpSimulationParamsAction;
@@ -196,7 +196,6 @@ public:
   void drawInitialStates(ModelInstance::Model *pModelInstance, bool inherited, const ModelInfo &modelInfo);
   void handleCollidingConnections();
 
-
   void setExtentRectangle(const QRectF rectangle, bool moveToCenter);
   void setIsCustomScale(bool enable) {mIsCustomScale = enable;}
   bool isCustomScale() {return mIsCustomScale;}
@@ -228,8 +227,6 @@ public:
   bool isMovingComponentsAndShapes() {return mIsMovingComponentsAndShapes;}
   void setRenderingLibraryPixmap(bool renderingLibraryPixmap) {mRenderingLibraryPixmap = renderingLibraryPixmap;}
   bool isRenderingLibraryPixmap() {return mRenderingLibraryPixmap;}
-  void setSharpLibraryPixmap(bool sharpLibraryPixmap) {mSharpLibraryPixmap = sharpLibraryPixmap;}
-  bool useSharpLibraryPixmap() {return mSharpLibraryPixmap;}
   QList<ShapeAnnotation*> getShapesList() {return mShapesList;}
   QList<ShapeAnnotation*> getInheritedShapesList() {return mInheritedShapesList;}
   QAction* getManhattanizeAction() {return mpManhattanizeAction;}
@@ -246,7 +243,7 @@ public:
   QAction* getRotateAntiClockwiseAction() {return mpRotateAntiClockwiseAction;}
   QAction* getFlipHorizontalAction() {return mpFlipHorizontalAction;}
   QAction* getFlipVerticalAction() {return mpFlipVerticalAction;}
-  bool performElementCreationChecks(LibraryTreeItem *pLibraryTreeItem, QString *name, QString *defaultPrefix);
+  bool performElementCreationChecks(const QString &nameStructure, bool partial, QString *name, QString *defaultPrefix);
   static ModelInstance::Component* createModelInstanceComponent(ModelInstance::Model *pModelInstance, const QString &name, const QString &className, bool isConnector);
   bool addComponent(QString className, QPointF position);
   void addComponentToView(QString name, LibraryTreeItem *pLibraryTreeItem, QString annotation, QPointF position,
@@ -256,6 +253,7 @@ public:
   void addElementToOutOfSceneList(Element *pElement) {mOutOfSceneElementsList.append(pElement);}
   void addInheritedElementToList(Element *pElement) {mInheritedElementsList.append(pElement);}
   void addElementToClass(Element *pElement);
+  static void addUsesAnnotation(const QString &insertedClassName, const QString &containingClassName, bool updateParentText);
   void addElementItem(Element *pElement);
   void removeElementItem(Element *pElement);
   void deleteElement(Element *pElement);
@@ -286,6 +284,7 @@ public:
   void removeConnectionsFromView();
   void deleteInheritedConnectionFromList(LineAnnotation *pConnectionLineAnnotation) {mInheritedConnectionsList.removeOne(pConnectionLineAnnotation);}
   int numberOfElementConnections(Element *pElement, LineAnnotation *pExcludeConnectionLineAnnotation = 0);
+  QString getConnectorName(Element *pConnector);
   QList<LineAnnotation*> getTransitionsList() {return mTransitionsList;}
   void addTransitionToView(LineAnnotation *pTransitionLineAnnotation, bool inherited);
   void addTransitionToClass(LineAnnotation *pTransitionLineAnnotation);
@@ -358,6 +357,8 @@ public:
   void fitInViewInternal();
   void emitResetDynamicSelect();
   void showReplaceSubModelDialog(QString name);
+  void addErrorTextShape();
+  void removeErrorTextShape();
 private:
   void createActions();
   bool isClassDroppedOnItself(LibraryTreeItem *pLibraryTreeItem);
@@ -370,7 +371,6 @@ private:
   Element* stateElementAtPosition(QPoint position);
   static bool updateElementConnectorSizingParameter(GraphicsView *pGraphicsView, QString className, Element *pElement);
   Element* getConnectorElement(ModelInstance::Connector *pConnector);
-  QString getConnectorName(Element *pConnector);
   bool handleDoubleClickOnComponent(QMouseEvent *event);
   void uncheckAllShapeDrawingActions();
   void setOriginAdjustAndInitialize(ShapeAnnotation* shapeAnnotation);
@@ -397,6 +397,7 @@ private:
   void omsOneShapeContextMenu(ShapeAnnotation *pShapeAnnotation, QMenu *pMenu);
   void omsOneComponentContextMenu(Element *pComponent, QMenu *pMenu);
   void omsMultipleItemsContextMenu(QMenu *pMenu);
+  void getCoOrdinateSystemAndGraphics(QStringList &coOrdinateSystemList, QStringList &graphicsList);
 signals:
   void manhattanize();
   void deleteSignal();
@@ -424,7 +425,7 @@ signals:
   void updateDynamicSelect(double time);
   void resetDynamicSelect();
 public slots:
-  void addConnection(Element *pComponent);
+  void addConnection(Element *pComponent, bool createConnector = false);
   void removeCurrentConnection();
   void deleteConnection(LineAnnotation *pConnectionLineAnnotation);
   void addTransition(Element *pComponent);
@@ -439,7 +440,8 @@ public slots:
   void copyItems();
   void pasteItems();
   void clearSelection(QGraphicsItem *pSelectGraphicsItem = 0);
-  void addClassAnnotation(bool alwaysAdd = true);
+  void addClassAnnotation();
+  void showParameters();
   void showGraphicsViewProperties();
   void showRenameDialog();
   void showSimulationParamsDialog();
@@ -562,6 +564,7 @@ public:
   GraphicsView* getIconGraphicsView() {return mpIconGraphicsView;}
   UndoStack* getUndoStack() {return mpUndoStack;}
   BaseEditor* getEditor() {return mpEditor;}
+  bool isDiagramViewLoaded() const {return mDiagramViewLoaded;}
   void setModelClassPathLabel(QString path) {mpModelClassPathLabel->setText(path);}
   void setModelFilePathLabel(QString path) {mpModelFilePathLabel->setText(path);}
   QVBoxLayout* getMainLayout() {return mpMainLayout;}
