@@ -354,6 +354,7 @@ QString Helper::stepReturn;
 QString Helper::attachToRunningProcess;
 QString Helper::attachToRunningProcessTip;
 QString Helper::reportIssue;
+QString Helper::crashTest;
 QString Helper::parsingFailedJson;
 QString Helper::expandAll;
 QString Helper::collapseAll;
@@ -662,6 +663,7 @@ void Helper::initHelperVariables()
   Helper::attachToRunningProcess = tr("Attach to Running Process");
   Helper::attachToRunningProcessTip = tr("Attach the debugger to running process");
   Helper::reportIssue = tr("Report Issue");
+  Helper::crashTest = tr("Crash Test");
   Helper::parsingFailedJson = tr("Parsing of JSON file failed");
   Helper::expandAll = tr("Expand All");
   Helper::collapseAll = tr("Collapse All");
@@ -755,7 +757,7 @@ QString GUIMessages::getMessage(int type)
     case SAME_COMPONENT_NAME:
       return tr("A component with the name <b>%1</b> already exists or is a Modelica keyword. Please choose another name.");
     case MISMATCHED_CONNECTORS_IN_CONNECT:
-      return tr("Connectors %1 and %2 are not compatible.");
+      return tr("Connectors <b>%1</b> and <b>%2</b> are not compatible.");
     case SAME_COMPONENT_CONNECT:
       return tr("You cannot connect a component to itself.");
     case NO_MODELICA_CLASS_OPEN:
@@ -821,7 +823,7 @@ QString GUIMessages::getMessage(int type)
     case ITEM_DROPPED_ON_ITSELF:
       return tr("You cannot drop an item on itself.");
     case MAKE_REPLACEABLE_IF_PARTIAL:
-      return tr("The <b>%1</b> <i>%2</i> is defined as <b>partial</b>.<br />The component will be added as a <b>replaceable</b> component.");
+      return tr("<b>%1</b> is defined as <b>partial</b>.<br />The component will be added as a <b>replaceable</b> component.");
     case INNER_MODEL_NAME_CHANGED:
       return tr("A component with the name <b>%1</b> already exists. The name is changed from <b>%1</b> to <b>%2</b>.<br /><br />This is probably wrong because the component is declared as <b>inner</b>.");
     case FMU_GENERATED:
@@ -902,6 +904,9 @@ QString GUIMessages::getMessage(int type)
       return tr("Please enter a script file.");
     case LIBRARY_INDEX_FILE_NOT_FOUND:
       return tr("Library index file <b>%1</b> doesn't exist.");
+    case VISUALIZATION_VECTORS_SCALING_ZOOMED_OUT_SCENE_TOO_MUCH:
+      return tr("Automatically-adjusted vector length scales zoomed out the scene too much. "
+                "Home position will be reset as if adjustable-length vectors were not drawn.");
     default:
       return "";
   }
