@@ -42,11 +42,6 @@
 #include <QApplication>
 #include <QCryptographicHash>
 #include <QByteArray>
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
-#include <QScreen>
-#else // QT_VERSION_CHECK
-#include <QDesktopWidget>
-#endif // QT_VERSION_CHECK
 #include <QGridLayout>
 #include <QStylePainter>
 #include <QPainter>
