@@ -641,7 +641,7 @@ namespace IAEX
                   pPlotCurve->addYAxisValue(d);
                 }
                 // set the curve data
-                pPlotCurve->setData(pPlotCurve->getXAxisVector(), pPlotCurve->getYAxisVector(), pPlotCurve->getSize());
+                pPlotCurve->plotData();
               }
               gCell->mpPlotWindow->getPlot()->addPlotCurve(pPlotCurve);
               pPlotCurve->attach(gCell->mpPlotWindow->getPlot());
@@ -664,8 +664,7 @@ namespace IAEX
             }
           }
           gCell->mpPlotWindow->show();
-          gCell->mpPlotWindow->fitInView();
-          gCell->mpPlotWindow->getPlot()->getPlotZoomer()->setZoomBase(false);
+          gCell->mpPlotWindow->updatePlot();
         }
         else
         {
