@@ -123,8 +123,6 @@ private:
   QwtSeriesData<QPointF>* mpInteractiveData;
   QString mInteractiveModelName;
   bool mPrefixUnits;
-  bool mCanUseXPrefixUnits;
-  bool mCanUseYPrefixUnits;
   QMdiSubWindow *mpSubWindow;
 public:
   PlotWindow(QStringList arguments = QStringList(), QWidget *parent = 0, bool isInteractiveSimulation = false);
@@ -135,7 +133,13 @@ public:
   void initializePlot(QStringList arguments);
   void setVariablesList(QStringList variables);
   void setPlotType(PlotType type);
-  PlotType getPlotType();
+  bool isPlot() const {return mPlotType == PlotWindow::PLOT;}
+  bool isPlotAll() const {return mPlotType == PlotWindow::PLOTALL;}
+  bool isPlotParametric() const {return mPlotType == PlotWindow::PLOTPARAMETRIC;}
+  bool isPlotInteractive() const {return mPlotType == PlotWindow::PLOTINTERACTIVE;}
+  bool isPlotArray() const {return mPlotType == PlotWindow::PLOTARRAY;}
+  bool isPlotArrayParametric() const {return mPlotType == PlotWindow::PLOTARRAYPARAMETRIC;}
+  PlotType getPlotType() const {return mPlotType;}
   void initializeFile(QString file);
   void getStartStopTime(double &start, double &stop);
   void setupToolbar();
@@ -197,10 +201,6 @@ public:
   QString getFooter();
   bool getPrefixUnits() const;
   void setPrefixUnits(bool prefixUnits);
-  bool canUseXPrefixUnits() const;
-  void setCanUseXPrefixUnits(bool canUseXPrefixUnits);
-  bool canUseYPrefixUnits() const;
-  void setCanUseYPrefixUnits(bool canUseYPrefixUnits);
   void checkForErrors(QStringList variables, QStringList variablesPlotted);
   Plot* getPlot();
   void receiveMessage(QStringList arguments);
@@ -208,24 +208,29 @@ public:
   void setTime(double time){mTime = time;}
   double getTime() {return mTime;}
   void updateTimeText();
-  void updateCurves();
-  void updateYAxis(QPair<double, double> minMaxValues);
   void updatePlot();
+private:
+  void setInteractiveControls(bool enabled);
 signals:
   void closingDown();
+private slots:
+  void fitInView();
 public slots:
+  void updateCurves();
+  void updateYAxis(QPair<double, double> minMaxValues);
   void enableZoomMode(bool on);
   void enablePanMode(bool on);
   void exportDocument();
   void printPlot();
   void setGrid(int index);
-  void fitInView();
   void setLogX(bool on);
   void setLogY(bool on);
   void setAutoScale(bool on);
   bool toggleSign(PlotCurve *pPlotCurve, bool checked);
   void showSetupDialog();
   void showSetupDialog(QString variable);
+  void interactiveSimulationStarted();
+  void interactiveSimulationPaused();
 };
 
 //Exception classes
@@ -341,6 +346,7 @@ private:
   QLabel *mpYMaximumLabel;
   QLineEdit *mpYMaximumTextBox;
   QCheckBox *mpPrefixUnitsCheckbox;
+  bool mPrefixUnitsChanged = false;
   /* buttons */
   QPushButton *mpOkButton;
   QPushButton *mpApplyButton;
@@ -349,7 +355,7 @@ private:
 public:
   SetupDialog(PlotWindow *pPlotWindow);
   void selectVariable(QString variable);
-  bool setupPlotCurve(VariablePageWidget *pVariablePageWidget);
+  void setupPlotCurve(VariablePageWidget *pVariablePageWidget);
 public slots:
   void variableSelected(QListWidgetItem *current, QListWidgetItem *previous);
   void autoScaleChecked(bool checked);
